@@ -28,7 +28,7 @@ return(fit)
 function(data,period) {
 response <- data
 num.var <- dim(data)[2] -1
-fit <- matrix(NA,nrow=num.var,ncol=2)
+fit <- matrix(NaN,nrow=num.var,ncol=2)
 for (i in 1:num.var) {
 fits <- optimize(f=phaser,c(0,24),time=data[,1],response=data[,1+i],period=period,maximum=TRUE)
 fit[i,1] <- fits$maximum
