@@ -1,5 +1,5 @@
 "print.psych.fa" <-
-function(x,digits=2,all=FALSE,cut=NULL,sort=FALSE,...)  {
+function(x,digits=2,all=FALSE,cut=NULL,sort=FALSE,suppress.warnings=TRUE,...)  {
 if(!is.matrix(x) && !is.null(x$fa) && is.list(x$fa)) x <-x$fa   #handles the output from fa.poly
 if(!is.null(x$fn) ) {if(x$fn == "principal") {cat("Principal Components Analysis") } else {
  cat("Factor Analysis using method = ",x$fm )}}
@@ -164,23 +164,26 @@ if(!is.null(x$R2)) { stats.df <- t(data.frame(sqrt(x$R2),x$R2,2*x$R2 -1))
 
  rownames(stats.df) <- c("Correlation of scores with factors  ","Multiple R square of scores with factors ","Minimum correlation of possible factor scores ")
          colnames(stats.df) <- colnames(x$loadings)
- 
- cat("\nMeasures of factor score adequacy             \n")
- print(round(stats.df,digits))
- 
- 
+ }
+ badFlag <- FALSE
+ #however, if the solution is degenerate, don't print them
+  
 
-	 if( max(x$R2) > (1 + .Machine$double.eps) ) {
-	 cat("\n WARNING, the factor score fit indices suggest that the solution is degenerate. Try a different method of factor extraction.\n")
+   if( any(max(x$R2,na.rm=TRUE) > (1 + .Machine$double.eps) )) {badFlag <- TRUE
+      if (!suppress.warnings) {
+	cat("\n WARNING, the factor score fit indices suggest that the solution is degenerate. Try a different method of factor extraction.\n")
 	 warning("the factor score fit indices suggest that the solution is degenerate\n")}
-	 }
-	 
-	if(!is.null(x$stats$R2)) {cat("\nMeasures of factor score adequacy             ",colnames(x$loadings)  )
+	 } else {
+	
+	  cat("\nMeasures of factor score adequacy             \n")
+      print(round(stats.df,digits))
+
+	if(!is.null(x$stats$R2) && !badFlag) {cat("\nMeasures of factor score adequacy             ",colnames(x$loadings)  )
 	cat("\nCorrelation of scores with factors           ",round(sqrt(x$R2),digits))
 	cat("\nMultiple R square of scores with factors      " ,round(x$R2,digits))
 	  cat("\nMinimum correlation of factor score estimates ", round(2*x$R2 -1,digits)) }
 	  }
- 
+ }
  result <- list(Vaccounted=varex)
  invisible(result) 
 } 
